.. currentmodule:: disnake_compass

Rich Select Implementations
===========================

.. automodule:: disnake_compass.impl.component.select

Classes
-------

.. Not sure why we need to manually declare all members here...
.. attributetable:: disnake_compass.impl.component.select.BaseSelect

.. autoclass:: disnake_compass.impl.component.select.BaseSelect
    :members: disabled, max_values, min_values, placeholder, as_ui_component, callback, get_factory, get_manager, make_custom_id, set_factory, set_manager

.. attributetable:: disnake_compass.impl.component.select.RichStringSelect

.. autoclass:: disnake_compass.impl.component.select.RichStringSelect
    :members: disabled, options, max_values, min_values, placeholder, as_ui_component, callback, get_factory, get_manager, make_custom_id, set_factory, set_manager

.. attributetable:: disnake_compass.impl.component.select.RichUserSelect

.. autoclass:: disnake_compass.impl.component.select.RichUserSelect
    :members: disabled, max_values, min_values, placeholder, as_ui_component, callback, get_factory, get_manager, make_custom_id, set_factory, set_manager

.. attributetable:: disnake_compass.impl.component.select.RichRoleSelect

.. autoclass:: disnake_compass.impl.component.select.RichRoleSelect
    :members: disabled, max_values, min_values, placeholder, as_ui_component, callback, get_factory, get_manager, make_custom_id, set_factory, set_manager

.. attributetable:: disnake_compass.impl.component.select.RichMentionableSelect

.. autoclass:: disnake_compass.impl.component.select.RichMentionableSelect
    :members: disabled, max_values, min_values, placeholder, as_ui_component, callback, get_factory, get_manager, make_custom_id, set_factory, set_manager

.. attributetable:: disnake_compass.impl.component.select.RichChannelSelect

.. autoclass:: disnake_compass.impl.component.select.RichChannelSelect
    :members: channel_types, disabled, max_values, min_values, placeholder, as_ui_component, callback, get_factory, get_manager, make_custom_id, set_factory, set_manager
